==> bootstrap-styled-1.7.8.tgz: package/lib/utils/tests/index.test.js <==
'use strict';

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _makeTheme = require('../../theme/makeTheme');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('bootstrap-styled theme utils', function () {
  describe('makeScopedTheme', function () {
    it('should have makeScopedTheme defined', function () {
      expect(_index.makeScopedTheme).toBeDefined();
    });
    it('should have makeScopedTheme with a scoped theme', function () {
      var result = (0, _makeTheme.makeTheme)({ scopeName: { $white: 'pink' } });
      expect((0, _index.makeScopedTheme)({ $white: 'pink' }, 'scopeName')).toEqual(result);
    });
    it('should have makeScopedTheme with a scoped theme name', function () {
      expect((0, _index.makeScopedTheme)({})).toEqual(undefined);
    });
  });
  describe('makeScopedTheme wiht calculus', function () {
    it('should have calculated scoped theme', function () {
      var makeThemeTest = function makeThemeTest() {
        var v = {};
        v.$white = 'pink';
        v.$blue = v.$white;
        v['$blue-darker'] = (0, _color2.default)(v.$blue).darken(0.05).toString();
        return v;
      };
      var result = { $blue: 'pink', '$blue-darker': 'hsl(349.5, 100%, 83.3%)', $white: 'pink' };
      expect((0, _index.makeScopedTheme)(makeThemeTest(), 'scopeName').scopeName).toEqual(result);
      expect((0, _index.makeScopedTheme)(makeThemeTest(), 'scopeName')['$brand-primary']).toEqual('#0275d8');
      expect((0, _index.makeScopedTheme)(makeThemeTest(), 'scopeName').scopeName['$blue-darker']).toEqual(result['$blue-darker']);
    });
    it('should have makeScopedTheme with a scoped theme name', function () {
      expect((0, _index.makeScopedTheme)({})).toEqual(undefined);
    });
  });
  describe('createMakeTheme', function () {
    var themeListFunction = [_makeTheme.makeTheme, (0, _index.toMakeTheme)((0, _makeTheme.makeTheme)({
      '$headings-font-family': '"Helvetica"'
    }))];

    it('should have $headings-font-family equal to Helvetica', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });

    it('should override $headings-font-family to equal Arial', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme({
        '$headings-font-family': '"Arial"'
      })['$headings-font-family']).toBe('"Arial"');

      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });
  });

  describe('toMakeTheme', function () {
    it('should create a makeTheme', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme()['$headings-font-family']).toBe(theme['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme({
        '$headings-font-family': '"Arial"'
      })['$headings-font-family']).toBe('"Arial"');
    });
  });
});

==> bootstrap-styled-1.8.0.tgz: package/lib/utils/tests/index.test.js <==
'use strict';

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _makeTheme = require('../../theme/makeTheme');

var _index = require('../index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('bootstrap-styled theme utils', function () {
  describe('makeScopedTheme', function () {
    it('should have makeScopedTheme defined', function () {
      expect(_index.makeScopedTheme).toBeDefined();
    });
    it('should have makeScopedTheme with a scoped theme', function () {
      var result = (0, _makeTheme.makeTheme)({ scopeName: { $white: 'pink' } });
      expect((0, _index.makeScopedTheme)({ $white: 'pink' }, 'scopeName')).toEqual({ scopeName: result.scopeName });
    });
    it('should have makeScopedTheme with a scoped theme name', function () {
      expect((0, _index.makeScopedTheme)({})).toEqual(undefined);
    });
  });
  describe('makeScopedTheme wiht calculus', function () {
    it('should have calculated scoped theme', function () {
      var makeThemeTest = function makeThemeTest() {
        var v = {};
        v.$white = 'pink';
        v.$blue = v.$white;
        v['$blue-darker'] = (0, _color2.default)(v.$blue).darken(0.05).toString();
        return v;
      };
      var result = { $blue: 'pink', '$blue-darker': 'hsl(349.5, 100%, 83.3%)', $white: 'pink' };
      expect((0, _index.makeScopedTheme)(makeThemeTest(), 'scopeName').scopeName).toEqual(result);
      expect((0, _index.makeScopedTheme)(makeThemeTest(), 'scopeName').scopeName['$blue-darker']).toEqual(result['$blue-darker']);
    });
  });
  describe('createMakeTheme', function () {
    var themeListFunction = [_makeTheme.makeTheme, (0, _index.toMakeTheme)((0, _makeTheme.makeTheme)({
      '$headings-font-family': '"Helvetica"'
    }))];

    it('should have $headings-font-family equal to Helvetica', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });

    it('should override $headings-font-family to equal Arial', function () {
      var makeTheme = (0, _index2.default)(themeListFunction);
      expect(makeTheme({
        '$headings-font-family': '"Arial"'
      })['$headings-font-family']).toBe('"Arial"');

      expect(makeTheme()['$headings-font-family']).toBe('"Helvetica"');
    });
  });

  describe('toMakeTheme', function () {
    it('should create a makeTheme', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme()['$headings-font-family']).toBe(theme['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var theme = { '$headings-font-family': 'Comic' };
      var makeTheme = (0, _index.toMakeTheme)(theme);
      expect(makeTheme({
        '$headings-font-family': '"Arial"'
      })['$headings-font-family']).toBe('"Arial"');
    });
  });
  describe('toMakeScopedTheme', function () {
    it('should create a makeTheme froma  scopedTheme', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeScopedTheme)(scopedTheme);
      expect(makeTheme().scopeName['$headings-font-family']).toBe(scopedTheme.scopeName['$headings-font-family']);
    });

    it('should override $headings-font-family variable to be equal to Arial', function () {
      var scopedTheme = { scopeName: { '$headings-font-family': 'Comic' } };
      var makeTheme = (0, _index.toMakeScopedTheme)(scopedTheme);
      var customTheme = makeTheme({
        '$headings-font-family': '"Arial"'
      });
      expect(customTheme.scopeName['$headings-font-family']).toBe('"Arial"');
    });
  });
});
